tag_provider library

Classes

TagInputNotifier
A ChangeNotifier that manages the state and behavior of tags in a TagField.

Enums

TagInputLayout
Defines the layout options for displaying tags in a TagField.